OC.L10N.register(
    "spreed",
    {
    "None" : "يوق",
    "User" : "User",
    "Users" : "ئىشلەتكۈچىلەر",
    "Name" : "ئاتى",
    "Favorite" : "يىغقۇچ",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Contacts" : "ئالاقەداشلار",
    "Loading" : "Loading",
    "Groups" : "گۇرۇپپا",
    "Error" : "خاتالىق",
    "Close" : "ياپ",
    "Reply" : "جاۋاب قايتۇر",
    "Today" : "بۈگۈن",
    "Settings" : "تەڭشەكلەر",
    "Edit" : "تەھرىر",
    "Share link" : "Share link",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Password" : "ئىم",
    "Cancel" : "ۋاز كەچ",
    "Change password" : "ئىم ئۆزگەرت",
    "Rename" : "ئات ئۆزگەرت",
    "Send" : "يوللا",
    "Share" : "ھەمبەھىر"
},
"nplurals=1; plural=0;");
